Learn R Programming

changepoints (version 1.1.0)

huber_mean: Element-wise adaptive Huber mean estimator.

Description

Computes the element-wise adaptive Huber mean estimator.

Usage

huber_mean(x, tau)

Value

A numeric scalar corresponding to the adaptive Huber mean estimator.

Arguments

x

A numeric vector of observations.

tau

A numeric scalar corresponding to the robustification parameter (larger than 0).

Author

Haotian Xu

Examples

Run this code
set.seed(123)
y = rnorm(100)
mean(y)
huber_mean(y, 1.345)

Run the code above in your browser using DataLab