Perform local refinement for VAR1 change points detection.
local.refine.CV.VAR1(cpt_init, DATA, zeta_set, delta_local)A list with the following structure:
A vector of estimated change point locations (sorted in strictly increasing order)
A scalar of selected zeta by cross-validation
A integer vector of initial change points estimation (sorted in strictly increasing order).
A numeric matrix of observations with with horizontal axis being time, and vertical axis being dimensions.
A numeric vector of candidate tuning parameters for group lasso penalty.
A strictly integer scalar of minimum spacing for group lasso.
Daren Wang & Haotian Xu
Wang, Yu, Rinaldo and Willett (2019) <arxiv:1909.06359>