local.refine.VAR1: Local refinement for VAR1 change points detection.
Description
Perform local refinement for VAR1 change points detection.
Usage
local.refine.VAR1(cpt_init, DATA, zeta)
Value
An integer vector of locally refined change points estimation.
Arguments
- cpt_init
A integer vector of initial change points estimation (sorted in strictly increasing order).
- DATA
A numeric matrix of observations with with horizontal axis being time, and vertical axis being dimensions.
- zeta
A numeric scalar of lasso penalty.
Author
Daren Wang & Haotian Xu
References
Wang, Yu, Rinaldo and Willett (2019) <arxiv:1909.06359>.